@@ -1,11 +1,11 @@
-from pathlib import Path
+from __future__ import annotations
 
 from ..via_template import ViaTemplateActivator
 
 
 class FishActivator(ViaTemplateActivator):
     def templates(self):
-        yield Path("activate.fish")
+        yield "activate.fish"
 
 
 __all__ = [
