@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 from tempfile import mkdtemp
 
@@ -21,7 +23,7 @@ class TempAppData(AppDataDiskFolder):
         logging.debug("remove temporary app data folder %s", self.lock.path)
         safe_delete(self.lock.path)
 
-    def embed_update_log(self, distribution, for_py_version):
+    def embed_update_log(self, distribution, for_py_version):  # noqa: U100
         raise NotImplementedError
 
 
