@@ -1,25 +1,22 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 import logging
 import os
 from abc import ABCMeta
-
-from six import add_metaclass
+from pathlib import Path
 
 from virtualenv.info import fs_supports_symlink
-from virtualenv.util.path import Path
-from virtualenv.util.zipapp import ensure_file_on_disk
 
 from ..creator import Creator, CreatorMeta
 
 
 class ViaGlobalRefMeta(CreatorMeta):
     def __init__(self):
-        super(ViaGlobalRefMeta, self).__init__()
+        super().__init__()
         self.copy_error = None
         self.symlink_error = None
         if not fs_supports_symlink():
-            self.symlink = "the filesystem does not supports symlink"
+            self.symlink_error = "the filesystem does not supports symlink"
 
     @property
     def can_copy(self):
@@ -30,16 +27,32 @@ class ViaGlobalRefMeta(CreatorMeta):
         return not self.symlink_error
 
 
-@add_metaclass(ABCMeta)
-class ViaGlobalRefApi(Creator):
+class ViaGlobalRefApi(Creator, metaclass=ABCMeta):
     def __init__(self, options, interpreter):
-        super(ViaGlobalRefApi, self).__init__(options, interpreter)
-        self.symlinks = getattr(options, "copies", False) is False
+        super().__init__(options, interpreter)
+        self.symlinks = self._should_symlink(options)
         self.enable_system_site_package = options.system_site
 
+    @staticmethod
+    def _should_symlink(options):
+        # Priority of where the option is set to follow the order: CLI, env var, file, hardcoded.
+        # If both set at same level prefers copy over symlink.
+        copies, symlinks = getattr(options, "copies", False), getattr(options, "symlinks", False)
+        copy_src, sym_src = options.get_source("copies"), options.get_source("symlinks")
+        for level in ["cli", "env var", "file", "default"]:
+            s_opt = symlinks if sym_src == level else None
+            c_opt = copies if copy_src == level else None
+            if s_opt is True and c_opt is True:
+                return False
+            if s_opt is True:
+                return True
+            if c_opt is True:
+                return False
+        return False  # fallback to copy
+
     @classmethod
     def add_parser_arguments(cls, parser, interpreter, meta, app_data):
-        super(ViaGlobalRefApi, cls).add_parser_arguments(parser, interpreter, meta, app_data)
+        super().add_parser_arguments(parser, interpreter, meta, app_data)
         parser.add_argument(
             "--system-site-packages",
             default=False,
@@ -48,6 +61,8 @@ class ViaGlobalRefApi(Creator):
             help="give the virtual environment access to the system site-packages dir",
         )
         group = parser.add_mutually_exclusive_group()
+        if not meta.can_symlink and not meta.can_copy:
+            raise RuntimeError("neither symlink or copy method supported")
         if meta.can_symlink:
             group.add_argument(
                 "--symlinks",
@@ -74,20 +89,26 @@ class ViaGlobalRefApi(Creator):
         if text:
             pth = self.purelib / "_virtualenv.pth"
             logging.debug("create virtualenv import hook file %s", pth)
-            pth.write_text("import _virtualenv")
+            pth.write_text("import _virtualenv", encoding="utf-8")
             dest_path = self.purelib / "_virtualenv.py"
             logging.debug("create %s", dest_path)
-            dest_path.write_text(text)
+            dest_path.write_text(text, encoding="utf-8")
 
     def env_patch_text(self):
         """Patch the distutils package to not be derailed by its configuration files"""
-        with ensure_file_on_disk(Path(__file__).parent / "_virtualenv.py", self.app_data) as resolved_path:
-            text = resolved_path.read_text()
+        with self.app_data.ensure_extracted(Path(__file__).parent / "_virtualenv.py") as resolved_path:
+            text = resolved_path.read_text(encoding="utf-8")
             return text.replace('"__SCRIPT_DIR__"', repr(os.path.relpath(str(self.script_dir), str(self.purelib))))
 
     def _args(self):
-        return super(ViaGlobalRefApi, self)._args() + [("global", self.enable_system_site_package)]
+        return super()._args() + [("global", self.enable_system_site_package)]
 
     def set_pyenv_cfg(self):
-        super(ViaGlobalRefApi, self).set_pyenv_cfg()
+        super().set_pyenv_cfg()
         self.pyenv_cfg["include-system-site-packages"] = "true" if self.enable_system_site_package else "false"
+
+
+__all__ = [
+    "ViaGlobalRefMeta",
+    "ViaGlobalRefApi",
+]
