@@ -1,23 +1,19 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
 
-import six
 
-
-@six.add_metaclass(ABCMeta)
-class Discover(object):
+class Discover(metaclass=ABCMeta):
     """Discover and provide the requested Python interpreter"""
 
     @classmethod
-    def add_parser_arguments(cls, parser):
+    def add_parser_arguments(cls, parser):  # noqa: U100
         """Add CLI arguments for this discovery mechanisms.
 
         :param parser: the CLI parser
         """
         raise NotImplementedError
 
-    # noinspection PyUnusedLocal
     def __init__(self, options):
         """Create a new discovery mechanism.
 
@@ -25,12 +21,12 @@ class Discover(object):
         """
         self._has_run = False
         self._interpreter = None
+        self._env = options.env
 
     @abstractmethod
     def run(self):
         """Discovers an interpreter.
 
-
         :return: the interpreter ready to use for virtual environment creation
         """
         raise NotImplementedError
@@ -44,3 +40,8 @@ class Discover(object):
             self._interpreter = self.run()
             self._has_run = True
         return self._interpreter
+
+
+__all__ = [
+    "Discover",
+]
