@@ -1,10 +1,8 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 import logging
 import sys
 
-from virtualenv.util.six import ensure_str
-
 LEVELS = {
     0: logging.CRITICAL,
     1: logging.ERROR,
@@ -18,21 +16,18 @@ MAX_LEVEL = max(LEVELS.keys())
 LOGGER = logging.getLogger()
 
 
-def setup_report(verbosity):
+def setup_report(verbosity, show_pid=False):
     _clean_handlers(LOGGER)
     if verbosity > MAX_LEVEL:
         verbosity = MAX_LEVEL  # pragma: no cover
     level = LEVELS[verbosity]
     msg_format = "%(message)s"
-    filelock_logger = logging.getLogger("filelock")
     if level <= logging.DEBUG:
         locate = "module"
-        msg_format = "%(relativeCreated)d {} [%(levelname)s %({})s:%(lineno)d]".format(msg_format, locate)
-        filelock_logger.setLevel(level)
-    else:
-        filelock_logger.setLevel(logging.WARN)
-
-    formatter = logging.Formatter(ensure_str(msg_format))
+        msg_format = f"%(relativeCreated)d {msg_format} [%(levelname)s %({locate})s:%(lineno)d]"
+    if show_pid:
+        msg_format = f"[%(process)d] {msg_format}"
+    formatter = logging.Formatter(msg_format)
     stream_handler = logging.StreamHandler(stream=sys.stdout)
     stream_handler.setLevel(level)
     LOGGER.setLevel(logging.NOTSET)
@@ -47,3 +42,10 @@ def setup_report(verbosity):
 def _clean_handlers(log):
     for log_handler in list(log.handlers):  # remove handlers of libraries
         log.removeHandler(log_handler)
+
+
+__all__ = [
+    "LEVELS",
+    "MAX_LEVEL",
+    "setup_report",
+]
