@@ -1,8 +1,10 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 import logging
+import os
+from functools import partial
 
-from ..app_data import AppDataAction, AppDataDisabled, TempAppData
+from ..app_data import make_app_data
 from ..config.cli.parser import VirtualEnvConfigParser
 from ..report import LEVELS, setup_report
 from ..run.session import Session
@@ -14,31 +16,44 @@ from .plugin.discovery import get_discover
 from .plugin.seeders import SeederSelector
 
 
-def cli_run(args, options=None):
-    """Create a virtual environment given some command line interface arguments
+def cli_run(args, options=None, setup_logging=True, env=None):
+    """
+    Create a virtual environment given some command line interface arguments.
 
     :param args: the command line arguments
     :param options: passing in a ``VirtualEnvOptions`` object allows return of the parsed options
+    :param setup_logging: ``True`` if setup logging handlers, ``False`` to use handlers already registered
+    :param env: environment variables to use
     :return: the session object of the creation (its structure for now is experimental and might change on short notice)
     """
-    session = session_via_cli(args, options)
-    with session:
-        session.run()
-    return session
+    env = os.environ if env is None else env
+    of_session = session_via_cli(args, options, setup_logging, env)
+    with of_session:
+        of_session.run()
+    return of_session
 
 
-# noinspection PyProtectedMember
-def session_via_cli(args, options=None):
-    parser, elements = build_parser(args, options)
+def session_via_cli(args, options=None, setup_logging=True, env=None):
+    """
+    Create a virtualenv session (same as cli_run, but this does not perform the creation). Use this if you just want to
+    query what the virtual environment would look like, but not actually create it.
+
+    :param args: the command line arguments
+    :param options: passing in a ``VirtualEnvOptions`` object allows return of the parsed options
+    :param setup_logging: ``True`` if setup logging handlers, ``False`` to use handlers already registered
+    :param env: environment variables to use
+    :return: the session object of the creation (its structure for now is experimental and might change on short notice)
+    """
+    env = os.environ if env is None else env
+    parser, elements = build_parser(args, options, setup_logging, env)
     options = parser.parse_args(args)
     creator, seeder, activators = tuple(e.create(options) for e in elements)  # create types
-    session = Session(options.verbosity, options.app_data, parser._interpreter, creator, seeder, activators)
-    return session
+    of_session = Session(options.verbosity, options.app_data, parser._interpreter, creator, seeder, activators)
+    return of_session
 
 
-# noinspection PyProtectedMember
-def build_parser(args=None, options=None):
-    parser = VirtualEnvConfigParser(options)
+def build_parser(args=None, options=None, setup_logging=True, env=None):
+    parser = VirtualEnvConfigParser(options, os.environ if env is None else env)
     add_version_flag(parser)
     parser.add_argument(
         "--with-traceback",
@@ -47,14 +62,14 @@ def build_parser(args=None, options=None):
         default=False,
         help="on failure also display the stacktrace internals of virtualenv",
     )
-    _do_report_setup(parser, args)
+    _do_report_setup(parser, args, setup_logging)
     options = load_app_data(args, parser, options)
     handle_extra_commands(options)
 
     discover = get_discover(parser, args)
     parser._interpreter = interpreter = discover.interpreter
     if interpreter is None:
-        raise RuntimeError("failed to find interpreter for {}".format(discover))
+        raise RuntimeError(f"failed to find interpreter for {discover}")
     elements = [
         CreatorSelector(interpreter, parser),
         SeederSelector(interpreter, parser),
@@ -74,37 +89,36 @@ def build_parser_only(args=None):
 
 def handle_extra_commands(options):
     if options.upgrade_embed_wheels:
-        result = manual_upgrade(options.app_data)
+        result = manual_upgrade(options.app_data, options.env)
         raise SystemExit(result)
 
 
 def load_app_data(args, parser, options):
+    parser.add_argument(
+        "--read-only-app-data",
+        action="store_true",
+        help="use app data folder in read-only mode (write operations will fail with error)",
+    )
+    options, _ = parser.parse_known_args(args, namespace=options)
+
     # here we need a write-able application data (e.g. the zipapp might need this for discovery cache)
-    default_app_data = AppDataAction.default()
     parser.add_argument(
         "--app-data",
-        dest="app_data",
-        action=AppDataAction,
-        default="<temp folder>" if isinstance(default_app_data, AppDataDisabled) else default_app_data,
         help="a data folder used as cache by the virtualenv",
+        type=partial(make_app_data, read_only=options.read_only_app_data, env=options.env),
+        default=make_app_data(None, read_only=options.read_only_app_data, env=options.env),
     )
     parser.add_argument(
         "--reset-app-data",
-        dest="reset_app_data",
         action="store_true",
         help="start with empty app data folder",
-        default=False,
     )
     parser.add_argument(
         "--upgrade-embed-wheels",
-        dest="upgrade_embed_wheels",
         action="store_true",
         help="trigger a manual update of the embedded wheels",
-        default=False,
     )
     options, _ = parser.parse_known_args(args, namespace=options)
-    if options.app_data == "<temp folder>":
-        options.app_data = TempAppData()
     if options.reset_app_data:
         options.app_data.reset()
     return options
@@ -116,19 +130,27 @@ def add_version_flag(parser):
     parser.add_argument(
         "--version",
         action="version",
-        version="%(prog)s {} from {}".format(__version__, virtualenv.__file__),
-        help="display the version of the virtualenv package and it's location, then exit",
+        version=f"%(prog)s {__version__} from {virtualenv.__file__}",
+        help="display the version of the virtualenv package and its location, then exit",
     )
 
 
-def _do_report_setup(parser, args):
-    level_map = ", ".join("{}={}".format(logging.getLevelName(l), c) for c, l in sorted(list(LEVELS.items())))
+def _do_report_setup(parser, args, setup_logging):
+    level_map = ", ".join(f"{logging.getLevelName(l)}={c}" for c, l in sorted(LEVELS.items()))
     msg = "verbosity = verbose - quiet, default {}, mapping => {}"
     verbosity_group = parser.add_argument_group(
-        title="verbosity", description=msg.format(logging.getLevelName(LEVELS[3]), level_map),
+        title="verbosity",
+        description=msg.format(logging.getLevelName(LEVELS[3]), level_map),
     )
     verbosity = verbosity_group.add_mutually_exclusive_group()
     verbosity.add_argument("-v", "--verbose", action="count", dest="verbose", help="increase verbosity", default=2)
     verbosity.add_argument("-q", "--quiet", action="count", dest="quiet", help="decrease verbosity", default=0)
     option, _ = parser.parse_known_args(args)
-    setup_report(option.verbosity)
+    if setup_logging:
+        setup_report(option.verbosity)
+
+
+__all__ = [
+    "cli_run",
+    "session_via_cli",
+]
