@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from abc import ABCMeta, abstractmethod
 
 
@@ -25,7 +27,7 @@ class Seeder(metaclass=ABCMeta):
         raise NotImplementedError
 
     @abstractmethod
-    def run(self, creator):  # noqa: U100
+    def run(self, creator):
         """Perform the seed operation.
 
         :param creator: the creator (based of :class:`virtualenv.create.creator.Creator`) we used to create this \
