@@ -1,43 +1,30 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 import subprocess
-import sys
-
-import six
-
-if six.PY2 and sys.platform == "win32":
-    from . import _win_subprocess
-
-    Popen = _win_subprocess.Popen
-else:
-    Popen = subprocess.Popen
-
 
 CREATE_NO_WINDOW = 0x80000000
 
 
 def run_cmd(cmd):
     try:
-        process = Popen(
+        process = subprocess.Popen(
             cmd,
             universal_newlines=True,
             stdin=subprocess.PIPE,
             stderr=subprocess.PIPE,
             stdout=subprocess.PIPE,
+            encoding="utf-8",
         )
         out, err = process.communicate()  # input disabled
         code = process.returncode
     except OSError as error:
         code, out, err = error.errno, "", error.strerror
         if code == 2 and "file" in err:
-            # FileNotFoundError in Python >= 3.3
-            err = str(error)
+            err = str(error)  # FileNotFoundError in Python >= 3.3
     return code, out, err
 
 
 __all__ = (
-    "subprocess",
-    "Popen",
     "run_cmd",
     "CREATE_NO_WINDOW",
 )
