@@ -1,14 +1,10 @@
-from __future__ import absolute_import, unicode_literals
+from __future__ import annotations
 
 import logging
 import os
 import zipfile
-from contextlib import contextmanager
 
-from virtualenv.dirs import default_data_dir
-from virtualenv.info import IS_WIN, IS_ZIPAPP, ROOT
-from virtualenv.util.six import ensure_text
-from virtualenv.version import __version__
+from virtualenv.info import IS_WIN, ROOT
 
 
 def read(full_path):
@@ -24,25 +20,19 @@ def extract(full_path, dest):
     with zipfile.ZipFile(ROOT, "r") as zip_file:
         info = zip_file.getinfo(sub_file)
         info.filename = dest.name
-        zip_file.extract(info, ensure_text(str(dest.parent)))
+        zip_file.extract(info, str(dest.parent))
 
 
 def _get_path_within_zip(full_path):
-    sub_file = str(full_path)[len(ROOT) + 1 :]
+    full_path = os.path.abspath(str(full_path))
+    sub_file = full_path[len(ROOT) + 1 :]
     if IS_WIN:
         # paths are always UNIX separators, even on Windows, though __file__ still follows platform default
         sub_file = sub_file.replace(os.sep, "/")
     return sub_file
 
 
-@contextmanager
-def ensure_file_on_disk(path):
-    if IS_ZIPAPP:
-        base = default_data_dir() / "zipapp" / "extract" / __version__
-        with base.lock_for_key(path.name):
-            dest = base.path / path.name
-            if not dest.exists():
-                extract(path, dest)
-            yield dest
-    else:
-        yield path
+__all__ = [
+    "read",
+    "extract",
+]
