@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import sys
 from ast import literal_eval
@@ -44,7 +46,7 @@ def test_python(raise_on_non_source_class, activation_tester):
 
             file_at = {str(activate_script)!r}
             # CPython 2 requires non-ascii path open to be unicode
-            with open(file_at, "r") as file_handler:
+            with open(file_at, "r", encoding='utf-8') as file_handler:
                 content = file_handler.read()
             exec(content, {{"__file__": file_at}})
 
@@ -58,7 +60,7 @@ def test_python(raise_on_non_source_class, activation_tester):
             result = dedent(raw).splitlines()
             return result
 
-        def assert_output(self, out, raw, tmp_path):
+        def assert_output(self, out, raw, tmp_path):  # noqa: U100
             out = [literal_eval(i) for i in out]
             assert out[0] is None  # start with VIRTUAL_ENV None
 
@@ -72,7 +74,7 @@ def test_python(raise_on_non_source_class, activation_tester):
             # sys path contains the site package at its start
             new_sys_path = out[5]
 
-            new_lib_paths = {j for j in {str(i) for i in self._creator.libs}}
+            new_lib_paths = {str(i) for i in self._creator.libs}
             assert prev_sys_path == new_sys_path[len(new_lib_paths) :]
             assert new_lib_paths == set(new_sys_path[: len(new_lib_paths)])
 
