@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import re
 import sys
 from subprocess import PIPE, Popen, check_output
@@ -9,7 +11,12 @@ from virtualenv.util.error import ProcessCallFailed
 
 
 def test_main():
-    process = Popen([sys.executable, "-m", "virtualenv", "--help"], universal_newlines=True, stdout=PIPE)
+    process = Popen(
+        [sys.executable, "-m", "virtualenv", "--help"],
+        universal_newlines=True,
+        stdout=PIPE,
+        encoding="utf-8",
+    )
     out, _ = process.communicate()
     assert not process.returncode
     assert out
@@ -51,7 +58,8 @@ def test_fail_with_traceback(raise_on_session_done, tmp_path, capsys):
     assert err == ""
 
 
-def test_session_report_full(session_app_data, tmp_path, capsys):
+@pytest.mark.usefixtures("session_app_data")
+def test_session_report_full(tmp_path, capsys):
     run_with_catch([str(tmp_path)])
     out, err = capsys.readouterr()
     assert err == ""
@@ -72,7 +80,8 @@ def _match_regexes(lines, regexes):
         assert comp_regex.match(line), line
 
 
-def test_session_report_minimal(session_app_data, tmp_path, capsys):
+@pytest.mark.usefixtures("session_app_data")
+def test_session_report_minimal(tmp_path, capsys):
     run_with_catch([str(tmp_path), "--activators", "", "--without-pip"])
     out, err = capsys.readouterr()
     assert err == ""
@@ -84,11 +93,13 @@ def test_session_report_minimal(session_app_data, tmp_path, capsys):
     _match_regexes(lines, regexes)
 
 
-def test_session_report_subprocess(session_app_data, tmp_path):
+@pytest.mark.usefixtures("session_app_data")
+def test_session_report_subprocess(tmp_path):
     # when called via a subprocess the logging framework should flush and POSIX line normalization happen
     out = check_output(
         [sys.executable, "-m", "virtualenv", str(tmp_path), "--activators", "powershell", "--without-pip"],
-        universal_newlines=True,
+        text=True,
+        encoding="utf-8",
     )
     lines = out.split("\n")
     regexes = [
