@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 from pathlib import Path
 
@@ -9,16 +11,16 @@ from testing.py_info import read_fixture
 sys.path.append(str(Path(__file__).parent))
 
 
-@pytest.fixture
+@pytest.fixture()
 def py_info(py_info_name):
     return read_fixture(py_info_name)
 
 
-@pytest.fixture
+@pytest.fixture()
 def mock_files(mocker):
     return lambda paths, files: path.mock_files(mocker, paths, files)
 
 
-@pytest.fixture
+@pytest.fixture()
 def mock_pypy_libs(mocker):
     return lambda pypy, libs: path.mock_pypy_libs(mocker, pypy, libs)
