@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from abc import ABCMeta, abstractmethod
 from itertools import chain
 from operator import attrgetter as attr
@@ -67,7 +69,7 @@ class PathMockABC(FakeDataABC, Path):
         yield from map(self.joinpath, self.contained_fake_names)
 
 
-def MetaPathMock(filelist):
+def MetaPathMock(filelist):  # noqa: N802
     """
     Metaclass that creates a `PathMock` class with the `filelist` defined.
     """
@@ -75,7 +77,7 @@ def MetaPathMock(filelist):
 
 
 def mock_files(mocker, pathlist, filelist):
-    PathMock = MetaPathMock(set(filelist))
+    PathMock = MetaPathMock(set(filelist))  # noqa: N806
     for path in pathlist:
         mocker.patch(path, PathMock)
 
