@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import os
 import sys
@@ -15,7 +17,7 @@ from virtualenv.seed.wheels.embed import BUNDLE_FOLDER, BUNDLE_SUPPORT
 from virtualenv.util.path import safe_delete
 
 
-@pytest.mark.slow
+@pytest.mark.slow()
 @pytest.mark.parametrize("copies", [False, True] if fs_supports_symlink() else [True])
 def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies):
     current = PythonInfo.current_system()
@@ -113,9 +115,6 @@ def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies)
         post_run = set(site_package.iterdir()) - patch_files
         assert not post_run, "\n".join(str(i) for i in post_run)
 
-    if sys.version_info[0:2] == (3, 4) and os.environ.get("PIP_REQ_TRACKER"):
-        os.environ.pop("PIP_REQ_TRACKER")
-
 
 @contextlib.contextmanager
 def read_only_dir(d):
@@ -143,14 +142,15 @@ def read_only_app_data(temp_app_data):
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest, read_only_app_data, monkeypatch):
+@pytest.mark.usefixtures("read_only_app_data")
+def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest):
     dest = tmp_path / "venv"
     result = cli_run(["--seeder", "app-data", "--creator", current_fastest, "-vv", str(dest)])
     assert result
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fastest, temp_app_data, monkeypatch):
+def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fastest, temp_app_data):
     dest = tmp_path / "venv"
     cmd = [
         "--seeder",
@@ -175,7 +175,7 @@ def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fast
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest, temp_app_data, monkeypatch):
+def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest, temp_app_data):
     dest = tmp_path / "venv"
     cmd = [
         "--seeder",
@@ -198,9 +198,10 @@ def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest
         assert cli_run(["--read-only-app-data"] + cmd)
 
 
-@pytest.mark.slow
+@pytest.mark.slow()
 @pytest.mark.parametrize("pkg", ["pip", "setuptools", "wheel"])
-def test_base_bootstrap_link_via_app_data_no(tmp_path, coverage_env, current_fastest, session_app_data, pkg):
+@pytest.mark.usefixtures("session_app_data", "current_fastest", "coverage_env")
+def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg):
     create_cmd = [str(tmp_path), "--seeder", "app-data", f"--no-{pkg}"]
     result = cli_run(create_cmd)
     assert not (result.creator.purelib / pkg).exists()
@@ -208,12 +209,14 @@ def test_base_bootstrap_link_via_app_data_no(tmp_path, coverage_env, current_fas
         assert (result.creator.purelib / key).exists()
 
 
-def test_app_data_parallel_ok(tmp_path, temp_app_data):
+@pytest.mark.usefixtures("temp_app_data")
+def test_app_data_parallel_ok(tmp_path):
     exceptions = _run_parallel_threads(tmp_path)
     assert not exceptions, "\n".join(exceptions)
 
 
-def test_app_data_parallel_fail(tmp_path, temp_app_data, mocker):
+@pytest.mark.usefixtures("temp_app_data")
+def test_app_data_parallel_fail(tmp_path, mocker):
     mocker.patch("virtualenv.seed.embed.via_app_data.pip_install.base.PipInstall.build_image", side_effect=RuntimeError)
     exceptions = _run_parallel_threads(tmp_path)
     assert len(exceptions) == 2
@@ -228,7 +231,7 @@ def _run_parallel_threads(tmp_path):
     def _run(name):
         try:
             cli_run(["--seeder", "app-data", str(tmp_path / name), "--no-pip", "--no-setuptools"])
-        except Exception as exception:  # noqa
+        except Exception as exception:
             as_str = str(exception)
             exceptions.append(as_str)
 
