@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 from datetime import datetime
 from pathlib import Path
@@ -36,11 +38,11 @@ def app_data(tmp_path_factory, for_py_version, next_pip_wheel):
                     "found_date": "2000-01-01T00:00:00.000000Z",
                     "release_date": "2000-01-01T00:00:00.000000Z",
                     "source": "periodic",
-                }
+                },
             ],
-        }
+        },
     )
-    yield app_data_
+    return app_data_
 
 
 def test_version_embed(app_data, for_py_version):
